@@ -1,5 +1,4 @@
-"""
-pytest-github is a plugin for py.test that allows tests to reference github issues for skip/xfail handling.
+"""Pytest-github is a py.test plugin to skip/xfail tests based on github issue status.
 
 :copyright: see LICENSE for details
 :license: MIT, see LICENSE for more details.
@@ -44,7 +43,7 @@ def pytest_addoption(parser):
                     dest='github_cfg_file',
                     default='github.yml',
                     metavar='GITHUB_CFG',
-                    help='GitHub configuration file (default: %default)')
+                    help='GitHub configuration file (default: %(default)s')
     group.addoption('--github-username',
                     action='store',
                     dest='github_username',
@@ -198,8 +197,11 @@ class GitHubPytestPlugin(object):
                 # warnings.warn(errstr, Warning)
 
             issue = self._issue_cache[issue_url]
-
-            issue_labels = [l.name for l in issue.labels]
+            try:
+                labels = iter(issue.labels)
+            except TypeError:  # github3.py 1.0.0+ uses instance method
+                labels = issue.labels()
+            issue_labels = [l.name for l in labels]
 
             # if the issue is open and isn't considered "completed" by any of the issue labels ...
             if not issue.is_closed() and not set(self.completed_labels).intersection(issue_labels):
@@ -238,7 +240,7 @@ class GitHubPytestPlugin(object):
                     (username, repository, number) = self.__parse_issue_url(url)
                     try:
                         self._issue_cache[url] = self.api.issue(username, repository, number)
-                    except (AttributeError, github3.models.GitHubError) as e:
+                    except (AttributeError, github3.exceptions.GitHubError) as e:
                         errstr = "Unable to inspect github issue %s - %s" % (url, str(e))
                         warnings.warn(errstr, Warning)
 
